@@ -1,5 +1,5 @@
-from .registration.decorator import Tktl
+from .registration.decorator import Tktl  # noqa: F401
 
 __author__ = """Carlo Mazzaferro"""
 __email__ = "carlo.mazzaferro@taktile.com"
-__version__ = "0.3.10"
+__version__ = "0.5.6"
