@@ -1,16 +1,17 @@
 import os
-from typing import Dict
+from typing import Dict, Optional
 
 from pydantic import BaseSettings
 
 
 class Settings(BaseSettings):
     API_V1_STR: str = "/api/v1"
-    USERS_OPEN_REGISTRATION: bool = False
-    IN_TESTING = False
+    LOCAL_STACK: bool = False
+    E2E: bool = False
+    CI_RUNNER_NAME: Optional[str] = None
 
-    VERBOSE: bool = None
-    DEBUG: bool = None
+    VERBOSE: bool = False
+    DEBUG: bool = False
     WEB_URL: str = "https://app.taktile.com"
     TAKTILE_API_URL: str = "https://taktile-api.taktile.com"
     DEPLOYMENT_API_URL: str = "https://deployment-api.taktile.com"
@@ -18,10 +19,10 @@ class Settings(BaseSettings):
 
     TKTL_CONFIG_PATH: str = os.path.expanduser("~/.config/tktl")
     CONFIG_FILE_NAME: str = "config.json"
-    TAKTILE_API_KEY: str = None
+    TAKTILE_API_KEY: Optional[str] = None
     HELP_HEADERS_COLOR: str = "yellow"
     HELP_OPTIONS_COLOR: str = "green"
-    USE_CONSOLE_COLORS: str = True
+    USE_CONSOLE_COLORS: bool = True
     HELP_COLORS_DICT: Dict = {
         "help_headers_color": "yellow",
         "help_options_color": "green",
