@@ -2,9 +2,9 @@ from collections.abc import Sequence
 from functools import singledispatch
 from typing import Any, Type
 
-import numpy
-import pandas
-import pyarrow
+import numpy  # type: ignore
+import pandas  # type: ignore
+import pyarrow  # type: ignore
 
 from tktl.core.exceptions import UnsupportedInputTypeException
 from tktl.core.loggers import LOG
@@ -24,33 +24,33 @@ def serialize_arrow(model_input) -> pyarrow.Table:
 
 
 @serialize_arrow.register(Sequence)
-def _(model_input):
+def _sequence(model_input):
     return _do_serialize_with_fallback(
         arrow.SequenceSerializer, model_input=model_input
     )
 
 
 @serialize_arrow.register(dict)
-def _(model_input):
+def _dict(model_input):
     return _do_serialize_with_fallback(
         arrow.SequenceSerializer, model_input=model_input
     )
 
 
 @serialize_arrow.register(numpy.ndarray)
-def _(model_input):
+def _ndarry(model_input):
     return _do_serialize_with_fallback(arrow.ArraySerializer, model_input=model_input)
 
 
 @serialize_arrow.register(pandas.DataFrame)
-def _(model_input):
+def _df(model_input):
     return _do_serialize_with_fallback(
         arrow.DataFrameSerializer, model_input=model_input
     )
 
 
 @serialize_arrow.register(pandas.Series)
-def _(model_input):
+def _series(model_input):
     return _do_serialize_with_fallback(arrow.SeriesSerializer, model_input=model_input)
 
 
