@@ -1,10 +1,19 @@
 from collections.abc import Iterable, Sequence
 from functools import singledispatch
-from typing import List, Optional, Type, Union
+from typing import (  # type: ignore
+    Any,
+    Dict,
+    List,
+    Optional,
+    Type,
+    Union,
+    _GenericAlias,
+    _SpecialForm,
+)
 
-import numpy
-import pandas
-from pandas.core.dtypes.inference import is_sequence
+import numpy  # type: ignore
+import pandas  # type: ignore
+from pandas.core.dtypes.inference import is_sequence  # type: ignore
 from pydantic import create_model
 from pydantic.main import ModelMetaclass
 
@@ -26,8 +35,8 @@ from tktl.core.t import RestSchemaTypes
 
 @singledispatch
 def to_pydantic(
-    value, name: str = RestSchemaTypes.SINGLE_VALUE.value, unique_id: str = None
-) -> Type[CustomDeserializingModelT]:
+    value: Any, name: str = RestSchemaTypes.SINGLE_VALUE.value, unique_id: str = None
+) -> Union[Type[CustomDeserializingModelT], Type[_GenericAlias], _GenericAlias]:
     """
     Single dispatch function for serializing values of each of the supported kinds. Each
     of the dispatched functions' implementation is tailored for one of Taktile's supported
@@ -48,14 +57,13 @@ def to_pydantic(
     single_value_model : CustomDeserializingModelT
         The Pydantic-based model
     """
-
     single_value_model = get_single_value_model(value)
     single_value_model.__name__ = get_model_unique_name(name=name, unique_id=unique_id)
     return single_value_model
 
 
 @to_pydantic.register
-def _(
+def _custom(
     value: ModelMetaclass,
     name: str = RestSchemaTypes.CUSTOM_MODEL.value,
     unique_id: str = None,
@@ -66,7 +74,7 @@ def _(
 
 
 @to_pydantic.register
-def _(
+def _df(
     value: pandas.DataFrame,
     name: str = RestSchemaTypes.DATAFRAME.value,
     unique_id: str = None,
@@ -108,7 +116,7 @@ def _(
     index_type = type(next((t for t in value.index)))
     type_map["index"] = (index_type, None)
 
-    base_model = create_model(name, **type_map)  # noqa
+    base_model = create_model(name, **type_map)  # type: ignore
     inner_model_unique_id = get_model_unique_name(
         name, unique_id=f"{unique_id}__dt_validate"
     )
@@ -120,7 +128,7 @@ def _(
 
 
 @to_pydantic.register
-def _(
+def _series(
     value: pandas.Series,
     name: str = RestSchemaTypes.SERIES.value,
     unique_id: str = None,
@@ -143,11 +151,11 @@ def _(
     types = (type(v) for k, v in value.to_dict().items() if not pandas.isna(v))
     var_type = next(types)  # type of first item that is not None
     if var_type == bool:
-        var_type = Union[var_type, float]
+        var_type = Union[var_type, float]  # type: ignore
     if nullable:
-        var_type = Optional[var_type]
-    type_map[type_name] = (List[var_type], None)
-    base_model = create_model(name, **type_map)  # noqa
+        var_type = Optional[var_type]  # type: ignore
+    type_map[type_name] = (List[var_type], None)  # type: ignore
+    base_model = create_model(name, **type_map)  # type: ignore
     series_model = get_series_model(
         series=value, base_model=base_model, example=example_map
     )
@@ -156,7 +164,7 @@ def _(
 
 
 @to_pydantic.register
-def _(
+def _array(
     value: numpy.ndarray, name: str = RestSchemaTypes.ARRAY.value, unique_id: str = None
 ) -> Type[CustomDeserializingModelT]:
     as_list = value.tolist()
@@ -176,7 +184,7 @@ def _(
 
 
 @to_pydantic.register
-def _(
+def _sequence(
     value: Sequence, name: str = RestSchemaTypes.SEQUENCE.value, unique_id: str = None
 ) -> Type[CustomDeserializingModelT]:
     if isinstance(value, list) or isinstance(value, tuple):
@@ -212,7 +220,7 @@ def _(
 
 
 @to_pydantic.register
-def _(
+def _dict(
     value: dict, name: str = RestSchemaTypes.DICT.value, unique_id: str = None
 ) -> Type[CustomDeserializingModelT]:
     mapping_model = _dict_model(value=value, name=name)
@@ -221,6 +229,20 @@ def _(
     return dict_model
 
 
+@to_pydantic.register
+def _generic(
+    value: _GenericAlias, name: str = RestSchemaTypes.ANY.value, unique_id: str = None,
+) -> Type[_GenericAlias]:
+    return value
+
+
+@to_pydantic.register
+def _any(
+    value: _SpecialForm, name: str = RestSchemaTypes.ANY.value, unique_id: str = None,
+) -> _GenericAlias:
+    return Union[Dict, List, Any]
+
+
 def _dict_model(value, name):
     types = {k: (type(v), v) for k, v in value.items()}
     return create_model(name, **types)
@@ -233,7 +255,7 @@ def _get_df_example(example_map):
     return Config
 
 
-def get_model_unique_name(name: str, unique_id: str) -> str:
+def get_model_unique_name(name: str, unique_id: Optional[str]) -> str:
     return name if not unique_id else f"{name}__{unique_id}"
 
 
