@@ -2,7 +2,7 @@ import functools
 import itertools
 import os
 import time
-from typing import List
+from typing import List, Sequence
 
 from tktl.core.exceptions import WrongPathError
 
@@ -77,4 +77,5 @@ def lru_cache(timeout: int, maxsize: int = 128, typed: bool = False):
     return wrapper_cache
 
 
-flatten = lambda x: list(itertools.chain.from_iterable(x))
+def flatten(x: Sequence) -> List:
+    return list(itertools.chain.from_iterable(x))
