@@ -1,9 +1,8 @@
 import functools
-import warnings
 from abc import ABC, abstractmethod
-from typing import Any, Callable, List, Optional, Tuple, Union
+from typing import Any, Callable, Dict, List, Optional, Tuple, Union
 
-import pandas
+import pandas  # type: ignore
 
 from tktl.core.exceptions import exceptions
 from tktl.core.t import EndpointKinds
@@ -23,11 +22,34 @@ class Endpoint(ABC):
     output_schema: EndpointOutputSchema
     explain_input_schema: Optional[EndpointInputSchema]
 
-    def __init__(self, func: Callable, profile_columns: Optional[List] = None):
+    def __init__(
+        self,
+        func: Callable,
+        profile_columns: Optional[List] = None,
+        disable_rest_validation: bool = True,
+    ):
         self._func = func
         self.profile_columns = (
             [str(c) for c in profile_columns] if profile_columns is not None else None
         )
+        self.disable_rest_validation = disable_rest_validation
+
+    @property
+    def has_arrow_sample_data(self):
+        return (
+            self.input_schema.supports_arrow_sample_data
+            and self.output_schema.supports_arrow_sample_data
+        )
+
+    @property
+    def has_rest_sample_data(self):
+        if self.disable_rest_validation:
+            return False
+        else:
+            return (
+                self.input_schema.supports_rest_sample_data
+                and self.output_schema.supports_rest_sample_data
+            )
 
     @property
     def func(self):
@@ -59,10 +81,12 @@ class Endpoint(ABC):
 
 class TabularEndpoint(Endpoint):
     explain_input_schema: Optional[EndpointInputSchema]
-    KIND: str = EndpointKinds.TABULAR
+    KIND: EndpointKinds = EndpointKinds.TABULAR
 
-    def __init__(self, func, X, y, profile_columns):
-        super().__init__(func, profile_columns)
+    def __init__(self, func, X, y, profile_columns, disable_rest_validation):
+        super().__init__(
+            func, profile_columns, disable_rest_validation=disable_rest_validation
+        )
         self.input_schema = EndpointInputSchema(
             value=X, endpoint_kind=self.KIND, endpoint_name=self.func.__name__
         )
@@ -86,7 +110,7 @@ class TabularEndpoint(Endpoint):
     def _profiling_supported(self) -> Union[bool, pandas.Series]:
         if (
             not self.input_schema.pandas_convertible
-            and not self.output_schema.pandas_convertible
+            or not self.output_schema.pandas_convertible
         ):
 
             return False
@@ -129,8 +153,10 @@ class TabularEndpoint(Endpoint):
 class BinaryEndpoint(TabularEndpoint):
     KIND = EndpointKinds.BINARY
 
-    def __init__(self, func, X, y, profile_columns):
-        super().__init__(func, X, y, profile_columns)
+    def __init__(self, func, X, y, profile_columns, disable_rest_validation=False):
+        super().__init__(
+            func, X, y, profile_columns, disable_rest_validation=disable_rest_validation
+        )
 
     @property
     def profiling_supported(self):
@@ -143,8 +169,10 @@ class BinaryEndpoint(TabularEndpoint):
 class RegressionEndpoint(TabularEndpoint):
     KIND = EndpointKinds.REGRESSION
 
-    def __init__(self, func, X, y, profile_columns):
-        super().__init__(func, X, y, profile_columns)
+    def __init__(self, func, X, y, profile_columns, disable_rest_validation=False):
+        super().__init__(
+            func, X, y, profile_columns, disable_rest_validation=disable_rest_validation
+        )
 
     @property
     def profiling_supported(self):
@@ -162,8 +190,15 @@ class CustomEndpoint(Endpoint):
 
     KIND = EndpointKinds.CUSTOM
 
-    def __init__(self, func, payload_model=None, response_model=None, X=None, y=None):
-        super().__init__(func)
+    def __init__(
+        self,
+        func,
+        payload_model=None,
+        response_model=None,
+        X=None,
+        y=None,
+        disable_rest_validation=False,
+    ):
         try:
             assert isinstance(func, Callable)
         except AssertionError:
@@ -172,15 +207,16 @@ class CustomEndpoint(Endpoint):
         models_defined = payload_model and response_model
         x_and_y_defined = (X is not None) and (y is not None)
         if not models_defined and not x_and_y_defined:
-            raise ValueError(
-                "For custom endpoints, either define sample data or payload models"
-            )
+            disable_rest_validation = True
+            payload_model = response_model = Union[Dict, List]
 
         if models_defined and x_and_y_defined:
             raise ValueError(
                 "For custom endpoints, either define sample data or payload models"
             )
 
+        super().__init__(func, disable_rest_validation=disable_rest_validation)
+
         self.input_schema = EndpointInputSchema(
             value=X,
             endpoint_kind=self.KIND,
@@ -212,6 +248,7 @@ class Tktl:
         y: Any = None,
         payload_model=None,
         response_model=None,
+        disable_rest_validation: bool = False,
         profile_columns: Optional[List] = None,
     ):
         """Register function as a Taktile endpoint
@@ -235,6 +272,8 @@ class Tktl:
         response_model:
             Type hint used for documenting and validating response. Used in
             custom endpoints only.
+        disable_rest_validation: bool
+            If true, skip Rest schema validation
         profile_columns: List, optional
             List of column names for which to run profiling. Used in binary
             and regression endpoints only.
@@ -244,6 +283,9 @@ class Tktl:
         Callable
             Wrapped function
         """
+        endpoint: Union[
+            TabularEndpoint, RegressionEndpoint, BinaryEndpoint, CustomEndpoint
+        ]
         if func is None:
             return functools.partial(
                 self.endpoint,
@@ -252,19 +294,32 @@ class Tktl:
                 y=y,
                 payload_model=payload_model,
                 response_model=response_model,
+                disable_rest_validation=disable_rest_validation,
                 profile_columns=profile_columns,
             )
         if kind == "tabular":
             endpoint = TabularEndpoint(
-                func=func, X=X, y=y, profile_columns=profile_columns
+                func=func,
+                X=X,
+                y=y,
+                profile_columns=profile_columns,
+                disable_rest_validation=disable_rest_validation,
             )
         elif kind == "regression":
             endpoint = RegressionEndpoint(
-                func=func, X=X, y=y, profile_columns=profile_columns
+                func=func,
+                X=X,
+                y=y,
+                profile_columns=profile_columns,
+                disable_rest_validation=disable_rest_validation,
             )
         elif kind == "binary":
             endpoint = BinaryEndpoint(
-                func=func, X=X, y=y, profile_columns=profile_columns
+                func=func,
+                X=X,
+                y=y,
+                profile_columns=profile_columns,
+                disable_rest_validation=disable_rest_validation,
             )
         elif kind == "custom":
             endpoint = CustomEndpoint(
@@ -273,6 +328,7 @@ class Tktl:
                 response_model=response_model,
                 X=X,
                 y=y,
+                disable_rest_validation=disable_rest_validation,
             )
         else:
             raise exceptions.ValidationException(f"Unknown endpoint kind: '{kind}'")
