@@ -1,9 +1,10 @@
 from abc import ABC, abstractmethod
-from typing import Any, Dict, List, Sequence, Tuple, Type
+from typing import Any, Dict, List, Sequence, Tuple, Type, _GenericAlias  # type: ignore
 
-import numpy
-import pandas
+import numpy  # type: ignore
+import pandas  # type: ignore
 from pydantic import BaseModel
+from pydantic.main import ModelMetaclass
 
 from tktl.core.loggers import LOG
 from tktl.core.serializers import to_pydantic
@@ -16,11 +17,19 @@ from tktl.registration.validation import (
     series_convertible,
 )
 
-_SUPPORTED_TYPES = [pandas.DataFrame, pandas.Series, numpy.ndarray, Sequence, dict]
+_SUPPORTS_ARROW_SAMPLE_DATA = [
+    pandas.DataFrame,
+    pandas.Series,
+    numpy.ndarray,
+    Sequence,
+    dict,
+]
+_SUPPORTS_REST_SAMPLE_DATA = _SUPPORTS_ARROW_SAMPLE_DATA + [ModelMetaclass]
+_SUPPORTED_TYPES = _SUPPORTS_REST_SAMPLE_DATA + [_GenericAlias]
 
 
-def check_supported_inputs(value):
-    return any([isinstance(value, t_) for t_ in _SUPPORTED_TYPES])
+def check_supported_inputs(value, types):
+    return any([isinstance(value, t_) for t_ in types])
 
 
 class EndpointSchema(ABC):
@@ -35,15 +44,21 @@ class EndpointSchema(ABC):
     ):
         self.endpoint_kind = endpoint_kind
         self.value = value
-        self.is_supported = check_supported_inputs(value)
+        self.is_supported = check_supported_inputs(value, _SUPPORTED_TYPES)
+        self.supports_rest_sample_data = check_supported_inputs(
+            value, _SUPPORTS_REST_SAMPLE_DATA
+        )
+        self.supports_arrow_sample_data = check_supported_inputs(
+            value, _SUPPORTS_ARROW_SAMPLE_DATA
+        )
         if not self.is_supported:
             LOG.warning(
-                f"Schema discovery not supported for inputs of type {type(value)}"
+                f"Endpoint '{endpoint_name}': schema discovery not supported for inputs of type {type(value)}"
             )
         if user_defined_model:
             value = user_defined_model
 
-        self.pydantic: CustomDeserializingModelT = to_pydantic(
+        self.pydantic: Type[CustomDeserializingModelT] = to_pydantic(
             value, unique_id=f"{endpoint_name}__{self.KIND}"
         )
 
@@ -111,5 +126,5 @@ def walk_sequence_schema(schema: Dict, shapes=()) -> Tuple[Tuple[int], str]:
     if schema["type"] == "array":
         shapes += (schema["maxItems"],)
         return walk_sequence_schema(schema["items"], shapes=shapes)
-    if schema["type"] != "array":
+    else:
         return shapes, schema["type"]
